@@ -15,46 +15,53 @@ options(rmarkdown.html_vignette.check_title = FALSE)
 #  library(stringr)
 #  library(coloc)
 
+## ---- message=FALSE, warning=FALSE, include=FALSE-----------------------------
+temp1 <- tempfile(fileext=".zip")
+download.file("https://master.dl.sourceforge.net/project/exampledata/env_new.zip", temp1)
+load(unz(temp1,"env_new.RData"))
+close(file(temp1))
+rm(temp1)
+
 ## ---- results = 'hide', echo=TRUE, message=FALSE, warning=FALSE, eval=FALSE----
-#  gwasDF <- fread("https://raw.githubusercontent.com/dingruofan/exampleData/master/gwas/AD/gwasDFsub.txt")
+#  gwasDF <- fread("https://master.dl.sourceforge.net/project/exampledata/gwasDFsub.txt")
 #  tissueSiteDetail="Brain - Cerebellum"
 
-## ---- eval=FALSE--------------------------------------------------------------
-#  head(gwasDF)
+## ---- eval=TRUE---------------------------------------------------------------
+head(gwasDF)
 
 ## ---- results = 'hide', echo=TRUE, message=FALSE, warning=FALSE, eval=FALSE----
 #  sentinelSnpDF <- xQTLanalyze_getSentinelSnp(gwasDF, pValueThreshold = 5e-08)
 
-## ---- eval=FALSE--------------------------------------------------------------
-#  sentinelSnpDF
+## ---- eval=TRUE---------------------------------------------------------------
+sentinelSnpDF
 
 ## ---- results = 'hide', echo=TRUE, message=FALSE, warning=FALSE, eval=FALSE----
 #  traitsAll <- xQTLanalyze_getTraits(sentinelSnpDF, detectRange=1e6, tissueSiteDetail=tissueSiteDetail)
 
-## ---- eval=FALSE--------------------------------------------------------------
-#  traitsAll
+## ---- eval=TRUE---------------------------------------------------------------
+traitsAll
 
 ## ---- results = 'hide', echo=TRUE, message=FALSE, warning=FALSE, eval=FALSE----
-#  output <- xQTLanalyze_coloc(gwasDF, "CLNK", tissueSiteDetail=tissueSiteDetail) # using gene symbol
+#  output <- xQTLanalyze_coloc(gwasDF, "ENSG00000109684", tissueSiteDetail=tissueSiteDetail) # using gene symbol
 
-## ---- eval=FALSE--------------------------------------------------------------
-#  output$coloc_Out_summary
+## ---- eval=TRUE---------------------------------------------------------------
+output$coloc_Out_summary
 
 ## ---- results = 'hide', echo=TRUE, message=FALSE, warning=FALSE, eval=FALSE----
 #  outputs <- rbindlist(lapply( unique(traitsAll$gencodeId), function(x){ # using gencode ID.
 #             xQTLanalyze_coloc(gwasDF, x, tissueSiteDetail=tissueSiteDetail, method = "Both")$colocOut }))
 
-## ---- eval=FALSE--------------------------------------------------------------
-#  outputs
+## ---- eval=TRUE---------------------------------------------------------------
+outputs
 
 ## ---- results = 'hide', echo=TRUE, message=FALSE, warning=FALSE, eval=FALSE----
-#  xQTLvisual_eqtl("ENSG00000109684.14")
+#  xQTLvisual_eqtl("ENSG00000109684")
 
 ## ---- eqtl_multiple_tissues, fig.align = 'center', out.width = "80%", echo=FALSE----
 # knitr::include_graphics("images/quick_start/eQTL_multiple_tissue.png")
 
 ## ---- results = 'hide', echo=TRUE, message=FALSE, warning=FALSE, eval=FALSE----
-#  eqtlAsso <- xQTLdownload_eqtlAllAsso(gene="ENSG00000109684.14",
+#  eqtlAsso <- xQTLdownload_eqtlAllAsso(gene="ENSG00000109684",
 #                                       tissueLabel = tissueSiteDetail)
 #  gwasEqtldata <- merge(gwasDF, eqtlAsso[,.(rsid=snpId, position=pos, maf, pValue)],
 #                        by=c("rsid", "position"), suffixes = c(".gwas",".eqtl"))
@@ -80,7 +87,7 @@ options(rmarkdown.html_vignette.check_title = FALSE)
 # knitr::include_graphics("images/quick_start/eqtl_legendF.png")
 
 ## ---- results = 'hide', echo=TRUE, message=FALSE, warning=FALSE, eval=FALSE----
-#  xQTLvisual_eqtlExp("rs13120565", "ENSG00000109684.14", tissueSiteDetail = tissueSiteDetail)
+#  xQTLvisual_eqtlExp("rs13120565", "ENSG00000109684", tissueSiteDetail = tissueSiteDetail)
 
 ## ---- exp.png, fig.align = 'center', out.width = "45%", echo=FALSE------------
 # knitr::include_graphics("images/quick_start/exp.png")
@@ -93,7 +100,7 @@ options(rmarkdown.html_vignette.check_title = FALSE)
 # knitr::include_graphics("images/quick_start/xQTLvisual_locusCombine.png")
 
 ## ---- results = 'hide', echo=TRUE, message=FALSE, warning=FALSE, eval=FALSE----
-#  multi_tissue_coloc <- xQTLvisual_coloc(gene="ENSG00000109684.14", variantName="rs13120565",
+#  multi_tissue_coloc <- xQTLvisual_coloc(gene="ENSG00000109684", variantName="rs13120565",
 #                                        tissueLabels = c("Brain - Cerebellar Hemisphere",
 #                                                          "Brain - Cerebellum", "Thyroid", "Lung",
 #                                                          "Cells - EBV-transformed lymphocytes"))
